---
name: "Warning"
about: Please, open issue in https://foss.heptapod.net and not on Github.

---

# Warning

Transonic development is hosted in https://foss.heptapod.net and issues should
be opened in https://foss.heptapod.net/fluiddyn/transonic/-/issues.

Please do not open an issue here on Github. Note that you can login in
https://foss.heptapod.net with your Github account.
